## 0.10.2

- Bugfix: `init` command fail in the case that the configuration file does not exist. [#37][]

## 0.10.1

- Add KMS support for Node.js [#35][]

## 0.10.0

- Split the configuration file [#33][]
- Bugfix

## 0.9.0

- Pull request [#28][]: Single file upload support ([@ijin][])
- Adjust some outputs
- Add `rollback` command [#29][]
  - Remove `configuration.alias` from the configuration file
  - Add `default_alias` to the configuration file
  - Add `versioning` to the configuration file

## 0.8.2

- Pull request [#27][]: Adjust final capacity depending on publishing lambda function or not ([@ijin][])

## 0.8.1

- Exclusion list support [#26][]

## 0.8.0

- Add invoke command [#18][] [#25][]
- Allow archiving without `virtualenv` [#23][] [#25][]
- Initial support `node.js` runtime [#23][] [#25][]
- Bugfix [#24][] [#25][]

## 0.7.0

- Support CloudWatch Events [#22][] [#3][]

## 0.6.0

- Change the secret file format YAML -> JSON
- Reduce capacity of the archive
- Bugfix

## 0.5.2

- Bugfix

## 0.5.1

- Bugfix

## 0.5.0

- Add `-l`,`--no-libs` option to archive without all libraries [#20][] [#21][]
- Calculate and print the function's usage capacity [#19][] [#21][]

## 0.4.0

- Change configuration file option `secret: key` -> `secret: key_id` [#17][]
- Simplify importing of `lamvery.secret` [#17][]
- Lost jinja2 descriptor when call `encrypt` command with `-s` option [#17][]

## 0.3.3

- Exclude bin directory form archive(Reduce size of the archive file)

## 0.3.2

- Add some files to list of exclude from the archive

## 0.3.1

- Bugfix: Duplicate output on `deploy`

## 0.3.0

- Support jinja2 template in configuration file [#15][]

## 0.2.0

- Change default name of the configuration file to '.lamvery.yml'
- Change format of the configuration file (See: [README](https://github.com/marcy-terui/lamvery/blob/master/README.md#setup))
- Support passing some confidential informations using KMS [#8][]
- Add `encrypt` command
- Add `decrypt` command
- Adjust all outputs

## 0.1.0

- Support `profile` specification [#6][] [#10][]
- Change `publish` to command-line argument [#9][]

## 0.0.6

- Collect help messages

## 0.0.5

- Add `alias` option [#1][] [#7][]

## 0.0.4

- Add `region` option
- Refactoring

## 0.0.3

- Bugfix

## 0.0.2

- Bugfix

## 0.0.1

- Initial release

<!--- The following link definition list is generated by PimpMyChangelog --->
[#1]: https://github.com/marcy-terui/lamvery/issues/1
[#3]: https://github.com/marcy-terui/lamvery/issues/3
[#6]: https://github.com/marcy-terui/lamvery/issues/6
[#7]: https://github.com/marcy-terui/lamvery/issues/7
[#8]: https://github.com/marcy-terui/lamvery/issues/8
[#9]: https://github.com/marcy-terui/lamvery/issues/9
[#10]: https://github.com/marcy-terui/lamvery/issues/10
[#15]: https://github.com/marcy-terui/lamvery/issues/15
[#17]: https://github.com/marcy-terui/lamvery/issues/17
[#18]: https://github.com/marcy-terui/lamvery/issues/18
[#19]: https://github.com/marcy-terui/lamvery/issues/19
[#20]: https://github.com/marcy-terui/lamvery/issues/20
[#21]: https://github.com/marcy-terui/lamvery/issues/21
[#22]: https://github.com/marcy-terui/lamvery/issues/22
[#23]: https://github.com/marcy-terui/lamvery/issues/23
[#24]: https://github.com/marcy-terui/lamvery/issues/24
[#25]: https://github.com/marcy-terui/lamvery/issues/25
[#26]: https://github.com/marcy-terui/lamvery/issues/26
[#27]: https://github.com/marcy-terui/lamvery/issues/27
[#28]: https://github.com/marcy-terui/lamvery/issues/28
[#29]: https://github.com/marcy-terui/lamvery/issues/29
[#33]: https://github.com/marcy-terui/lamvery/issues/33
[#35]: https://github.com/marcy-terui/lamvery/issues/35
[#37]: https://github.com/marcy-terui/lamvery/issues/37
[@ijin]: https://github.com/ijin